@@ -3,14 +3,14 @@
 use http::Uri;
 
 #[derive(Debug, Copy, Clone, PartialEq, Eq, PartialOrd, Ord, Hash)]
-pub enum HttpRequestUri {
+pub enum RequestUri {
     Asterisk,
     AbsoluteUri,
     AbsPath,
     Authority,
 }
 
-impl From<&Uri> for HttpRequestUri {
+impl From<&Uri> for RequestUri {
     fn from(uri: &Uri) -> Self {
         if uri.scheme().is_some() {
             Self::AbsoluteUri
@@ -24,7 +24,7 @@ impl From<&Uri> for HttpRequestUri {
     }
 }
 
-impl From<Uri> for HttpRequestUri {
+impl From<Uri> for RequestUri {
     fn from(uri: Uri) -> Self {
         Self::from(&uri)
     }
@@ -37,8 +37,8 @@ mod tests {
     #[test]
     fn test_from_uri() {
         assert_eq!(
-            HttpRequestUri::from("*".parse::<Uri>().unwrap()),
-            HttpRequestUri::Asterisk
+            RequestUri::from("*".parse::<Uri>().unwrap()),
+            RequestUri::Asterisk
         );
 
         for uri in &[
@@ -46,21 +46,21 @@ mod tests {
             "http://www.w3.org",
         ] {
             assert_eq!(
-                HttpRequestUri::from(uri.parse::<Uri>().unwrap()),
-                HttpRequestUri::AbsoluteUri
+                RequestUri::from(uri.parse::<Uri>().unwrap()),
+                RequestUri::AbsoluteUri
             );
         }
 
         for uri in &["/pub/WWW/TheProject.html", "/"] {
             assert_eq!(
-                HttpRequestUri::from(uri.parse::<Uri>().unwrap()),
-                HttpRequestUri::AbsPath
+                RequestUri::from(uri.parse::<Uri>().unwrap()),
+                RequestUri::AbsPath
             );
         }
 
         assert_eq!(
-            HttpRequestUri::from("proxy.com".parse::<Uri>().unwrap()),
-            HttpRequestUri::Authority
+            RequestUri::from("proxy.com".parse::<Uri>().unwrap()),
+            RequestUri::Authority
         );
     }
 }
